Learn R Programming

mclust (version 3.0-0)

Defaults.Mclust: List of values controlling defaults for some MCLUST functions.

Description

A named list of values including an enumeration of models used as defaults in MCLUST functions.

Arguments

Value

  • A list with the following components:
  • emModelNamesA vector of character strings associated with multivariate models for which EM estimation is available in MCLUST. The current default is the following list: "EII": spherical, equal volume "VII": spherical, unequal volume "EEI": diagonal, equal volume and shape "VEI": diagonal, varying volume, equal shape "EVI": diagonal, equal volume, varying shape "VVI": diagonal, varying volume and shape "EEE": ellipsoidal, equal volume, shape, and orientation "EEV": ellipsoidal, equal volume and equal shape "VEV": ellipsoidal, equal shape "VVV": ellipsoidal, varying volume, shape, and orientation
  • hcModelNamesA vector of character strings associated with multivariate models for which model-based hierarchical clustering is available in MCLUST. The current default is the following list: "EII": spherical, equal volume "VII": spherical, unequal volume "EEE": ellipsoidal, equal volume, shape, and orientation "VVV": ellipsoidal, varying volume, shape, and orientation
  • bicPlotSymbolsA vector whose entries are either integers corresponding to graphics symbols or single characters used for plotting the BIC values output from Mclust and mclustBIC.
  • classPlotSymbolsA vector whose entries are either integers corresponding to graphics symbols or single characters for plotting data with classifications. Classes are assigned symbols in the given order.
  • warnA logical value indicating whether or not to issue certain warnings (usually involving singularity). Default: warn = TRUE.

References

C. Fraley and A. E. Raftery (2002). Model-based clustering, discriminant analysis, and density estimation. Journal of the American Statistical Association. C. Fraley and A. E. Raftery (2006). MCLUST Version 3: An R Package for Normal Mixture Modeling and Model-Based Clustering, Technical Report, Department of Statistics, University of Washington.

Details

A function mclustOptions is supplied for assigning values to the .Mclust list.

See Also

mclustOptions, Mclust, mclustBIC

Examples

Run this code
irisBIC <- Mclust(iris[,-5])
summary(irisBIC, iris[-5])

.Mclust
.Mclust <- mclustOptions(emModelNames = c("VII", "VVI", "VVV"))
.Mclust

irisBIC <- Mclust(iris[,-5])
summary(irisBIC, iris[-5])

.Mclust <- mclustOptions() # restore defaults
.Mclust

Run the code above in your browser using DataLab