Description Usage Arguments Value See Also Examples
Implements the expectation step of EM algorithm for parameterized Gaussian mixture models.
1 |
modelName |
A character string indicating the model. The help file for
|
data |
A numeric vector, matrix, or data frame of observations. Categorical variables are not allowed. If a matrix or data frame, rows correspond to observations and columns correspond to variables. |
parameters |
A names list giving the parameters of the model. The components are as follows:
|
warn |
A logical value indicating whether or not a warning should be issued
when computations fail. The default is |
... |
Catches unused arguments in indirect or list calls via |
A list including the following components:
modelName |
A character string identifying the model (same as the input argument). |
z |
A matrix whose |
parameters |
The input parameters. |
loglik |
The log-likelihood for the data in the mixture model. |
Attributes |
|
estepE, ...,
estepVVV,
em,
mstep,
mclust.options
mclustVariance
1 2 3 4 5 6 7 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.