hclass: Classifications from Hierarchical Agglomeration
Description
Determines the classifications corresponding to different numbers of groups
given merge pairs from hierarchical agglomeration.
Usage
hclass(hcPairs, G)
Arguments
hcPairs
A numeric two-column matrix in which the ith row gives the minimum
index for observations in each of the two clusters merged at the
ith stage of agglomerative hierarchical clustering.
G
An integer or vector of integers giving the number of clusters for which
the corresponding classfications are wanted.
Value
A matrix with length(G) columns, each column
corresponding to a classification. Columns are indexed by the character
representation of the integers in G.
References
C. Fraley and A. E. Raftery (2006).
MCLUST Version 3: An R Package for Normal Mixture Modeling
and Model-Based Clustering, Technical Report, Department of Statistics,
University of Washington.