mclust2Dplot(data, parameters=NULL, z=NULL,
classification=NULL, truth=NULL, uncertainty=NULL,
what = c("classification","uncertainty","errors"),
quantiles = c(0.75, 0.95), symbols=NULL, scale = FALSE,
xlim=NULL, ylim=NULL, CEX = 1, PCH = ".", identify = FALSE,
swapAxes = FALSE, ...)[i,k]th entry gives the
probability of observation i belonging to the kth class.
Used to compute classification and
uncertainty if those arguments arendata. If present argument z
will be ignored.classification
or z is also present,
this is used for displaying classification errors.z
will be ignored."classification"
(default), "errors", "uncertainty".classification.
Elements in symbols
correspond to classes in classification
in order of appearance in the observscale=FALSEC. Fraley and A. E. Raftery (2006). MCLUST Version 3: An R Package for Normal Mixture Modeling and Model-Based Clustering, Technical Report, Department of Statistics, University of Washington.
surfacePlot,
clPairs,
coordProj,
mclustOptionsfaithfulModel <- mclustModel(faithful,mclustBIC(faithful))
mclust2Dplot(faithful, parameters=faithfulModel$parameters,
z=faithfulModel$z, what = "classification", identify = TRUE)
mclust2Dplot(faithful, parameters=faithfulModel$parameters,
z=faithfulModel$z, what = "uncertainty", identify = TRUE)Run the code above in your browser using DataLab