hcModelNames
A vector of character strings associated with multivariate models for
which model-based hierarchical clustering is available in MCLUST.
The current default is the following list:
"EII": spherical, equal volume
"VII": spherical, unequal volume
"EEE
bicPlotSymbols
A vector whose entries are either integers corresponding to graphics
symbols or single characters for plotting for
classifications. Classes are assigned symbols in the given
order. The default is
c(EII=17,VII=2,EEI=16,EVI=10,VEI=13,VVI=
classPlotSymbols
A vector whose entries are either integers corresponding to graphics
symbols or single characters for plotting for
classifications. Classes are assigned symbols in the given order.
The default is c(17,0,10,4,11,18,6,7,3,16,2,12,8,15,1,9,