Description Usage Arguments Value See Also Examples
Converts a vector interpreted as a classification or partitioning into a numeric vector.
1 |
x |
A vector interpreted as a classification or partitioning. |
consec |
Logical value indicating whether or not to consecutive class numbers should be used . |
Numeric encoding of x.
When consec = TRUE, the distinct values in x are numbered by
the order in which they appear.
When consec = FALSE, each distinct value in x is numbered by
the index corresponding to its first appearance in x.
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.