Choose one or more of: "BIC", "classification",
"uncertainty". If the data dimension is less than 3,
"density" can also be chosen.
ylimBIC
Limits for the vertical axis of the BIC plot.
...
Other graphics parameters.
Value
Model-based clustering plots: BIC values used for choosing the number of
clusters. For data in more than two dimensions, a pairs plot of the showing
the classification, a coordinate projections of the data showing location of
the mixture components, classification, and uncertainty. For one- and two-
dimensional data, plots showing location of the mixture components,
classification, uncertainty, and density.
References
C. Fraley and A. E. Raftery (2002).
Model-based clustering, discriminant analysis, and density estimation.
Journal of the American Statistical Association 97:611-631.
C. Fraley and A. E. Raftery (2006).
MCLUST Version 3: An R Package for Normal Mixture Modeling
and Model-Based Clustering, Technical Report, Department of Statistics,
University of Washington.
Details
For more flexibility in plotting, use mclust1Dplot,
mclust2Dplot, surfacePlot, coordProj, or
randProj.