Description Usage Arguments Value See Also Examples
Plots the BIC values returned by the mclustBIC function.
1 2 3 4 5 6 |
x |
Output from |
G |
One or more numbers of components corresponding to models fit in |
modelNames |
One or more model names corresponding to models fit in |
symbols |
Either an integer or character vector assigning a plotting symbol to each
unique class in |
colors |
Either an integer or character vector assigning a color to each
unique class in |
xlab |
Optional label for the horizontal axis of the BIC plot. |
ylab |
Label for the vertical axis of the BIC plot. |
ylim |
Optional limits for the vertical axis of the BIC plot. |
legendArgs |
Arguments to pass to the |
... |
Other graphics parameters. |
A plot of the BIC values.
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.