mclustDAtrain. For multidimensional data,
the plot is a coordinate projection and the ellipses shown correspond to
the covariance matrices.plot.mclustDAtrain(x, data, dimens=c(1,2), symbols=NULL,
scale = FALSE, xlim=NULL, ylim=NULL, CEX = 1, ...)mclustDAtrain.c(1,2), in which the first
dimension is plotted against the second.classification. Elements in
symbols correspond to classes in classification in
sorted order. Default: If Gscale=FALSEC. Fraley and A. E. Raftery (2006). MCLUST Version 3: An R Package for Normal Mixture Modeling and Model-Based Clustering, Technical Report, Department of Statistics, University of Washington.
coordProj,
mclust1Dplot,
mclust2Dplot,
mclustOptionsodd <- seq(from = 1, to = nrow(iris), by = 2)
irisTrain <- mclustDAtrain(data = iris[odd,-5], labels = iris[odd,5])
plot(irisTrain, iris[odd,-5])Run the code above in your browser using DataLab