Learn R Programming

mclust (version 5.4.9)

diabetes: Diabetes data

Description

The data set contains three measurements made on 145 non-obese adult patients classified into three groups.

Usage

data(diabetes)

Arguments

Format

A data frame with the following variables:

class

The type of diabete: Normal, Overt, and Chemical.

glucose

Area under plasma glucose curve after a three hour oral glucose tolerance test (OGTT).

insulin

Area under plasma insulin curve after a three hour oral glucose tolerance test (OGTT).

sspg

Steady state plasma glucose.

Details

This dataset is not correct and it is provided here only for backward compatibility. Please refer to the correct version available in package rrcov.