The data set contains three measurements made on 145 non-obese adult patients classified into three groups.
data(diabetes)A data frame with the following variables:
The type of diabete: Normal, Overt, and Chemical.
Area under plasma glucose curve after a three hour oral glucose tolerance test (OGTT).
Area under plasma insulin curve after a three hour oral glucose tolerance test (OGTT).
Steady state plasma glucose.
This dataset is not correct and it is provided here only for backward compatibility. Please refer to the correct version available in package rrcov.